#!/bin/bash

## Script to automate the setting up of my working environment.


RED=$(tput setaf 1)
GREEN=$(tput setaf 2)
ORANGE=$(tput setaf 3)
NC=$(tput sgr0)

export RED
export GREEN
export ORANGE
export NC


#############
# DEFINE OS #
#############

if [ -z "$1" ]; then
  echo "Which OS are you using?"
  select OS in 'debian - ubuntu' 'arch - manjaro'; do
    case $OS in
      'debian - ubuntu' ) OS='debian'; break;;
      'arch - manjaro' ) OS='arch'; break;;
    esac
  done
else
  if [ "$1" = 'debian' ] || [ "$1" = 'ubuntu' ]; then
    OS='debian'
  elif [ "$1" = 'arch' ] || [ "$1" = 'manjaro' ]; then
    OS='arch'
  else
    echo "${ORANGE}Didn't understand OS argument${NC}"
    echo "Which OS are you using?"
    select OS in 'debian - ubuntu' 'arch - manjaro'; do
      case $OS in
        'debian - ubuntu' ) OS='debian'; break;;
        'arch - manjaro' ) OS='arch'; break;;
      esac
    done
  fi
fi
echo "Using $OS"
export OS

/bin/bash ~/SetupCockpit/separator.sh


###################
# Install scripts #
###################

echo "Installing scripts..."

if [ "$OS" = 'debian' ]; then
  /bin/bash ~/SetupCockpit/debian_based_installs.sh
elif [ "$OS" = 'arch' ]; then
  /bin/bash ~/SetupCockpit/arch_based_installs.sh
else
  echo "${RED} Didn't receive correct OS information, quitting...${NC}"
  exit 1
fi

/bin/bash ~/SetupCockpit/separator.sh


########################
# Update .bash_aliases #
########################

echo "Updating .bash_aliases..."
if cp ~/SetupCockpit/bash_aliases ~/.bash_aliases; then
  echo "${GREEN}Successfully updated .bash_aliases${NC}"
else
  echo "${ORANGE}There was a problem while updating .bash_aliases${NC}"
fi

/bin/bash ~/SetupCockpit/separator.sh


#################
# Configure Git #
#################

echo "Configuring Git..."

git config --global user.name "$USER@$(uname -n)"
git config --global user.email "tfranken@protonmail.com"
git config --global alias.ci "commit"
git config --global alias.co "checkout"
git config --global alias.st "status"
git config --global alias.br "branch"

/bin/bash ~/SetupCockpit/separator.sh


##############################################################################
# Add MIME type for reading .md files in Firefox (need to add extension too) #
##############################################################################

echo "Adding MIME type for .md files in Firefox..."
echo "${ORANGE}Remember to install the Firefox extension for it to work${NC}"

if [ -e ~/.local/share/mime/packages/text-markdown.xml ]; then
echo "<?xml version=\"1.0\"?>
<mime-info xmlns=\"http://www.freedesktop.org/standards/shared-mime-info\">
  <mime-type type=\"text/plain\">
    <glob pattern=\"*.md\"/>
    <glob pattern=\"*.mkd\"/>
    <glob pattern=\"*.markdown\"/>
  </mime-type>
</mime-info>" > ~/.local/share/mime/packages/text-markdown.xml
fi

/bin/bash ~/SetupCockpit/separator.sh


##################
# Clone projects #
##################

echo "Cloning projects..."

/bin/bash clone_projects.sh

/bin/bash ~/SetupCockpit/separator.sh


#######################
# Configure ProtonVPN #
#######################

echo "Configuring ProtonVPN..."

sudo protonvpn init && sudo protonvpn c --cc NL

/bin/bash ~/SetupCockpit/separator.sh
